==> purchaser-invoice-saas-client-0.0.55-sources.jar: com/xforceplus/purchaserinvoicesaas/controller/InvoiceOperateLogFeignApi.java <==
package com.xforceplus.purchaserinvoicesaas.controller;


/**
 * 用户操作行为履历feign客户端
 *
 * @author ultraman
 * @date 2022-07-04
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.purchaserinvoicesaas.entity.InvoiceOperateLog;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "purchaser-invoice-saas")
public interface InvoiceOperateLogFeignApi {

  /**
   * 通过id查询用户操作行为履历
   * @param  id
   * @return R
   */
  @GetMapping("/invoiceOperateLog/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增用户操作行为履历
   * @param invoiceOperateLog 用户操作行为履历
   * @return R
   */
  @PostMapping("/invoiceOperateLog/add")
  public R save(@RequestBody InvoiceOperateLog invoiceOperateLog);

  /**
   * 修改用户操作行为履历
   * @param invoiceOperateLog 用户操作行为履历
   * @return R
   */
  @PostMapping("/invoiceOperateLog/update")
  public R updateById(@RequestBody InvoiceOperateLog invoiceOperateLog);

  /**
   * 通过id删除用户操作行为履历
   * @param  id
   * @return R
   */
  @DeleteMapping("/invoiceOperateLog/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> purchaser-invoice-saas-client-0.0.167-sources.jar: com/xforceplus/purchaserinvoicesaas/controller/InvoiceOperateLogFeignApi.java <==
package com.xforceplus.purchaserinvoicesaas.controller;


/**
 * 用户操作行为履历feign客户端
 *
 * @author ultraman
 * @date 2023-01-09
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.purchaserinvoicesaas.entity.InvoiceOperateLog;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "purchaser-invoice-saas")
public interface InvoiceOperateLogFeignApi {

  /**
   * 通过id查询用户操作行为履历
   * @param  id
   * @return R
   */
  @GetMapping("/invoiceOperateLog/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增用户操作行为履历
   * @param invoiceOperateLog 用户操作行为履历
   * @return R
   */
  @PostMapping("/invoiceOperateLog/add")
  public R save(@RequestBody InvoiceOperateLog invoiceOperateLog);

  /**
   * 修改用户操作行为履历
   * @param invoiceOperateLog 用户操作行为履历
   * @return R
   */
  @PostMapping("/invoiceOperateLog/update")
  public R updateById(@RequestBody InvoiceOperateLog invoiceOperateLog);

  /**
   * 通过id删除用户操作行为履历
   * @param  id
   * @return R
   */
  @DeleteMapping("/invoiceOperateLog/del/{id}" )
  public R removeById(@PathVariable Long id);

}
